## Product details

Meet the Shark CarpetXpert with Stainstriker Technology, 2-in-1 upright deep carpet cleaner and built-in StainStriker spot & stain eliminator, combines Shark's powerful suction & PowerSpray high pressure spray to deliver unbeatable carpet cleaning* and the best tough stain elimination.** Two unique chemicals mix and activate on contact in the built-in tool to deliver 20X more stain-striking power *^ and instant odor removal^ on carpets, area rugs, upholstery and more. Includes a 3.5 inch reversible bristle stain tool, integrated crevice tool, 12oz Shark CarpetXpert Deep Clean Pro formula and 16oz Shark StainStriker OXY Multiplier formula.
UNBEATABLE DEEP CARPET CLEANING*: Shark's powerful suction and deep-cleaning innovation delivers unbeatable deep carpet cleaning* along with the best tough stain elimination** results
HANDHELD SPOT & STAIN ELIMINATOR: The first and only deep carpet cleaners with a built-in spot and stain remover designed to extend and clean stairs, carpet, upholstery and other isolated stains
STAINSTRIKER TECHNOLOGY: Two unique chemicals mix and activate on contact in the built-in handheld tool unleashing the power of OXY for 20X more stain-striking power leaving behind a fresh scent*^
CARPETXPERT TECHNOLOGY: Combines the action of a high-speed brushroll, PowerSpray high-pressure spray and powerful Shark suction to deliver unbeatable dirt and grime removal*
REMOVES ODORS: Instantly and permanently removes odors, including pet urine and smoke^
ULTRA-FAST DRY TIMES: Shark's CarpetXpert technology and powerful suction deliver ultra-fast dry times using dry-only mode without over soaking your carpets
WHATS INCLUDED: 3.5 inch reversible bristle stain tool, integrated crevice tool, 12oz Shark CarpetXpert Deep Clean Pro formula and 16oz Shark StainStriker OXY Multiplier formula.
*Shark CarpetXpert models vs. consumer carpet cleaners based on ASTM F2828 using included cleaning solution as of May 15, 2024. **Based on TM110, vs. extractor market, using included stain cleaner and best-performing accessory. *^vs. Shark Deep Clean Pro Formula. ^When using Shark cleaning solution.
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

Weight
16.98 lb
Has written warranty
Yes - Warranty Text
Recommended surface
Carpet, Upholstery
Rec. use
Residential
More details
## Directions

Instructions
See User Guide
## Warranty

Warranty information
Five (5) Year Limited Warranty

Please be aware that the warranty terms on items offered for sale by third party Marketplace sellers may differ from those displayed in this section (if any). To confirm warranty terms on an item offered for sale by a third party Marketplace seller, please use the 'Contact seller' feature on the third party Marketplace seller's information page and request the item's warranty terms prior to purchase.
Warranty url
https://support.sharkclean.com/hc/en-us/article_attachments/9942429409820
More details
## Ingredients

Ingredients
See bottle label
